==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Part/Gui/DlgPartImportStepImp.h <==
/***************************************************************************
 *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef DlgPartImportStepImp_H
#define DlgPartImportStepImp_H

#include "ui_DlgPartImportStep.h"


namespace PartGui {

class DlgPartImportStepImp : public QDialog, public Ui_DlgPartImportStep
{ 
    Q_OBJECT

public:
  DlgPartImportStepImp( QWidget* parent = 0, Qt::WindowFlags fl = 0 );
  ~DlgPartImportStepImp();

public Q_SLOTS:
  virtual void OnApply();
  virtual void onChooseFileName();

};

} // namespace PartGui

#endif // DlgPartImportStepImp_H

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Part/Gui/DlgPartImportStepImp.h <==
/***************************************************************************
 *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef DlgPartImportStepImp_H
#define DlgPartImportStepImp_H

#include <QDialog>
#include <memory>

namespace PartGui {
class Ui_DlgPartImportStep;

class DlgPartImportStepImp : public QDialog
{ 
    Q_OBJECT

public:
  DlgPartImportStepImp( QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags() );
  ~DlgPartImportStepImp();

public Q_SLOTS:
  virtual void OnApply();
  virtual void onChooseFileName();

private:
  std::unique_ptr<Ui_DlgPartImportStep> ui;
};

} // namespace PartGui

#endif // DlgPartImportStepImp_H
